@@ -1,7 +1,7 @@
 ;;; solar.el --- calendar functions for solar events
 
 ;; Copyright (C) 1992, 1993, 1995, 1997, 2001, 2002, 2003, 2004, 2005,
-;;   2006  Free Software Foundation, Inc.
+;;   2006, 2007  Free Software Foundation, Inc.
 
 ;; Author: Edward M. Reingold <reingold@cs.uiuc.edu>
 ;;	Denis B. Roegel <Denis.Roegel@loria.fr>
@@ -27,7 +27,7 @@
 ;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 ;; Boston, MA 02110-1301, USA.
 
-;;; Synched up with: FSF Emacs 22.1 CVS 2006-09-15
+;;; Synched up with: FSF Emacs 22 CVS 2007-03-30
 
 ;;; Commentary:
 
@@ -509,7 +509,7 @@ Result is in julian centuries of ephemeris time."
 (defun solar-date-next-longitude (d l)
   "First moment on or after Julian day number D when sun's longitude is a
 multiple of L degrees at calendar-location-name with that location's
-local time (including any daylight savings rules).
+local time (including any daylight saving rules).
 
 L must be an integer divisor of 360.
 
